Enum BufferFormat
enum BufferFormat
An enum expressing all Serde formats known to ICU4X.
Variants
-
Json Serialize using JavaScript Object Notation (JSON), using the
serde_jsoncrate.-
Bincode1 Serialize using the
bincodecrate, version 1.-
Postcard1 Serialize using the
postcardcrate, version 1.
Implementations
impl BufferFormat
fn check_available(self: &Self) -> Result<(), DataError>Returns an error if the buffer format is not enabled.
impl Clone for BufferFormat
fn clone(self: &Self) -> BufferFormat
impl Copy for BufferFormat
impl Debug for BufferFormat
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for BufferFormat
impl Freeze for BufferFormat
impl Hash for BufferFormat
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl PartialEq for BufferFormat
fn eq(self: &Self, other: &BufferFormat) -> bool
impl RefUnwindSafe for BufferFormat
impl Send for BufferFormat
impl StructuralPartialEq for BufferFormat
impl Sync for BufferFormat
impl Unpin for BufferFormat
impl UnsafeUnpin for BufferFormat
impl UnwindSafe for BufferFormat
impl<T> Any for BufferFormat
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for BufferFormat
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for BufferFormat
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for BufferFormat
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> ErasedDestructor for BufferFormat
impl<T> From for BufferFormat
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for BufferFormat
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for BufferFormat
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for BufferFormat
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for BufferFormat
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>