Enum DataErrorKind
enum DataErrorKind
A list specifying general categories of data provider error.
Errors may be caused either by a malformed request or by the data provider not being able to fulfill a well-formed request.
Variants
-
MarkerNotFound No data for the requested data marker. This is only returned by
DynamicDataProvider.-
IdentifierNotFound There is data for the data marker, but not for this particular data identifier.
-
InvalidRequest The request is invalid, such as a request for a singleton marker containing a data identifier.
-
InconsistentData(DataMarkerInfo) The data for two
DataMarkers is not consistent.-
Downcast(&'static str) An error occured during
Anydowncasting.-
Deserialize An error occured during
serdedeserialization.Check debug logs for potentially more information.
-
Custom An unspecified error occurred.
Check debug logs for potentially more information.
Implementations
impl DataErrorKind
const fn into_error(self: Self) -> DataErrorConverts this DataErrorKind into a DataError.
If possible, you should attach context using a
with_function.const fn with_marker(self: Self, marker: DataMarkerInfo) -> DataErrorCreates a DataError with a data marker context.
const fn with_str_context(self: Self, context: &'static str) -> DataErrorCreates a DataError with a string context.
fn with_type_context<T>(self: Self) -> DataErrorCreates a DataError with a type name context.
fn with_req(self: Self, marker: DataMarkerInfo, req: DataRequest<'_>) -> DataErrorCreates a DataError with a request context.
impl Clone for DataErrorKind
fn clone(self: &Self) -> DataErrorKind
impl Copy for DataErrorKind
impl Debug for DataErrorKind
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for DataErrorKind
fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result
impl Eq for DataErrorKind
impl Freeze for DataErrorKind
impl PartialEq for DataErrorKind
fn eq(self: &Self, other: &DataErrorKind) -> bool
impl RefUnwindSafe for DataErrorKind
impl Send for DataErrorKind
impl StructuralPartialEq for DataErrorKind
impl Sync for DataErrorKind
impl Unpin for DataErrorKind
impl UnsafeUnpin for DataErrorKind
impl UnwindSafe for DataErrorKind
impl<T> Any for DataErrorKind
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DataErrorKind
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DataErrorKind
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for DataErrorKind
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> ErasedDestructor for DataErrorKind
impl<T> From for DataErrorKind
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for DataErrorKind
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for DataErrorKind
fn to_string(self: &Self) -> String
impl<T, U> Into for DataErrorKind
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for DataErrorKind
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for DataErrorKind
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>