Struct DataResponse

struct DataResponse<M> { ... }
where
    M: DynamicDataMarker

A response object containing an object as payload and metadata about it.

Fields

metadata: DataResponseMetadata

Metadata about the returned object.

payload: DataPayload<M>

The object itself

Implementations

impl<M> DataResponse<M>

fn cast<M2>(self: Self) -> DataResponse<M2>
where
    M2: DynamicDataMarker<DataStruct = <M as >::DataStruct>

Convert between two DynamicDataMarker types that are compatible with each other with compile-time type checking.

This happens if they both have the same DynamicDataMarker::DataStruct type.

Can be used to erase the marker of a data payload in cases where multiple markers correspond to the same data struct.

For runtime dynamic casting, use [DataPayload::dynamic_cast_mut()].

impl<M> Clone for DataResponse<M>

fn clone(self: &Self) -> Self

impl<M> Debug for DataResponse<M>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<M> Freeze for DataResponse<M>

impl<M> RefUnwindSafe for DataResponse<M>

impl<M> Send for DataResponse<M>

impl<M> Sync for DataResponse<M>

impl<M> Unpin for DataResponse<M>

impl<M> UnsafeUnpin for DataResponse<M>

impl<M> UnwindSafe for DataResponse<M>

impl<T> Any for DataResponse<M>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DataResponse<M>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DataResponse<M>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DataResponse<M>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> ErasedDestructor for DataResponse<M>

impl<T> From for DataResponse<M>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DataResponse<M>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for DataResponse<M>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DataResponse<M>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DataResponse<M>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>