Struct DataMarkerAttributes
struct DataMarkerAttributes { ... }
An additional key to identify data beyond a DataLocale.
The is a loose wrapper around a string, with semantics defined by each DataMarker.
Implementations
impl DataMarkerAttributes
const fn try_from_str(s: &str) -> Result<&Self, AttributeParseError>Creates a borrowed
DataMarkerAttributesfrom a borrowed string.Returns an error if the string contains characters other than
[a-zA-Z0-9_\-].const fn try_from_utf8(code_units: &[u8]) -> Result<&Self, AttributeParseError>Attempts to create a borrowed
DataMarkerAttributesfrom a borrowed UTF-8 encoded byte slice.Examples
use *; let bytes = b"long-meter"; let marker = try_from_utf8.unwrap; assert_eq!;Errors
Returns an error if the byte slice contains code units other than
[a-zA-Z0-9_\-].const fn from_str_or_panic(s: &str) -> &SelfCreates a borrowed
DataMarkerAttributesfrom a borrowed string.Panics if the string contains characters other than
[a-zA-Z0-9_\-].const fn empty() -> &'static SelfCreates an empty
DataMarkerAttributes.const fn as_str(self: &Self) -> &strReturns this
DataMarkerAttributesas a&str.
impl Debug for DataMarkerAttributes
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Deref for DataMarkerAttributes
fn deref(self: &Self) -> &<Self as >::Target
impl Eq for DataMarkerAttributes
impl Freeze for DataMarkerAttributes
impl Hash for DataMarkerAttributes
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for DataMarkerAttributes
fn cmp(self: &Self, other: &DataMarkerAttributes) -> Ordering
impl PartialEq for DataMarkerAttributes
fn eq(self: &Self, other: &DataMarkerAttributes) -> bool
impl PartialOrd for DataMarkerAttributes
fn partial_cmp(self: &Self, other: &DataMarkerAttributes) -> Option<Ordering>
impl RefUnwindSafe for DataMarkerAttributes
impl Send for DataMarkerAttributes
impl Sized for DataMarkerAttributes
impl StructuralPartialEq for DataMarkerAttributes
impl Sync for DataMarkerAttributes
impl Unpin for DataMarkerAttributes
impl UnsafeUnpin for DataMarkerAttributes
impl UnwindSafe for DataMarkerAttributes
impl<P, T> Receiver for DataMarkerAttributes
impl<T> Any for DataMarkerAttributes
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DataMarkerAttributes
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DataMarkerAttributes
fn borrow_mut(self: &mut Self) -> &mut T