DataPayloadOr

Struct DataPayloadOr 

pub struct DataPayloadOr<M: DynamicDataMarker, O>(/* private fields */);
A container for data payloads with storage for something else.

The type parameter O is stored as part of the interior enum, leading to better stack size optimization. O can be as large as the DataPayload minus two words without impacting stack size.

Examples

Create and use DataPayloadOr:

use icu_locale_core::langid;
use icu_provider::hello_world::*;
use icu_provider::prelude::*;
use icu_provider::DataPayloadOr;

let response: DataResponse<HelloWorldV1> = HelloWorldProvider
    .load(DataRequest {
        id: DataIdentifierBorrowed::for_locale(&langid!("de").into()),
        ..Default::default()
    })
    .expect("Loading should succeed");

let payload_some =
    DataPayloadOr::<HelloWorldV1, ()>::from_payload(response.payload);
let payload_none = DataPayloadOr::<HelloWorldV1, ()>::from_other(());

assert_eq!(
    payload_some.get(),
    Ok(&HelloWorld {
        message: "Hallo Welt".into()
    })
);
assert_eq!(payload_none.get(), Err(&()));

Stack size comparison:

use icu_provider::prelude::*;
use icu_provider::DataPayloadOr;

const W: usize = size_of::<usize>();

// Data struct is 3 words:
icu_provider::data_marker!(SampleV1, [usize; 3]);

// DataPayload adds a word for a total of 4 words:
assert_eq!(W * 4, size_of::<DataPayload<SampleV1>>());

// Option<DataPayload> balloons to 5 words:
assert_eq!(W * 5, size_of::<Option<DataPayload<SampleV1>>>());

// But, using DataPayloadOr is the same size as DataPayload:
assert_eq!(W * 4, size_of::<DataPayloadOr<SampleV1, ()>>());

// The largest optimized Other type is two words smaller than the DataPayload:
assert_eq!(W * 4, size_of::<DataPayloadOr<SampleV1, [usize; 1]>>());
assert_eq!(W * 4, size_of::<DataPayloadOr<SampleV1, [usize; 2]>>());
assert_eq!(W * 5, size_of::<DataPayloadOr<SampleV1, [usize; 3]>>());

Implementations

Source

impl<M, O> DataPayloadOr<M, O>

pub fn from_payload(payload: DataPayload<M>) -> Self

Creates a DataPayloadOr from a DataPayload.

pub fn from_other(other: O) -> Self

Creates a DataPayloadOr from the other type O.

pub fn is_payload(&self) -> bool

Returns whether this object represents a DataPayload.

pub fn get<'a>( &'a self, ) -> Result<&'a <M::DataStruct as Yokeable<'a>>::Output, &'a O>

Gets the value from this DataPayload as Ok or the other type as Err.

pub fn into_inner(self) -> Result<DataPayload<M>, O>

Consumes this DataPayloadOr, returning either the wrapped DataPayload or the other type.

Source

impl<M> DataPayloadOr<M, ()>

pub fn none() -> Self

Convenience function to return the other type with value ()

pub fn get_option<'a>( &'a self, ) -> Option<&'a <M::DataStruct as Yokeable<'a>>::Output>

Convenience function to return Some or None for other type ()