Struct DataRequestMetadata

struct DataRequestMetadata { ... }

Metadata for data requests. This is currently empty, but it may be extended with options for tuning locale fallback, buffer layout, and so forth.

Fields

silent: bool

Silent requests do not log errors. This can be used for exploratory querying, such as fallbacks.

attributes_prefix_match: bool

Whether to allow prefix matches for the data marker attributes.

Implementations

impl Clone for DataRequestMetadata

fn clone(self: &Self) -> DataRequestMetadata

impl Copy for DataRequestMetadata

impl Debug for DataRequestMetadata

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Default for DataRequestMetadata

fn default() -> DataRequestMetadata

impl Eq for DataRequestMetadata

impl Freeze for DataRequestMetadata

impl Ord for DataRequestMetadata

fn cmp(self: &Self, other: &DataRequestMetadata) -> Ordering

impl PartialEq for DataRequestMetadata

fn eq(self: &Self, other: &DataRequestMetadata) -> bool

impl PartialOrd for DataRequestMetadata

fn partial_cmp(self: &Self, other: &DataRequestMetadata) -> Option<Ordering>

impl RefUnwindSafe for DataRequestMetadata

impl Send for DataRequestMetadata

impl StructuralPartialEq for DataRequestMetadata

impl Sync for DataRequestMetadata

impl Unpin for DataRequestMetadata

impl UnsafeUnpin for DataRequestMetadata

impl UnwindSafe for DataRequestMetadata

impl<T> Any for DataRequestMetadata

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DataRequestMetadata

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DataRequestMetadata

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DataRequestMetadata

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> ErasedDestructor for DataRequestMetadata

impl<T> From for DataRequestMetadata

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DataRequestMetadata

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for DataRequestMetadata

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DataRequestMetadata

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DataRequestMetadata

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>