Struct Data
struct Data<M: DataMarker> { ... }
Regular baked data: a trie for lookups and a slice of values
Implementations
impl<M: DataMarker> Data<M>
unsafe const fn from_trie_and_values_unchecked(trie: ZeroTrieSimpleAscii<&'static [u8]>, values: &'static [<M as >::DataStruct]) -> SelfConstruct from a trie and values
Safety
The actual values contained in the trie must be valid indices into
values
impl<M> Freeze for Data<M>
impl<M> RefUnwindSafe for Data<M>
impl<M> Send for Data<M>
impl<M> Sync for Data<M>
impl<M> Unpin for Data<M>
impl<M> UnsafeUnpin for Data<M>
impl<M> UnwindSafe for Data<M>
impl<M: $crate::fmt::Debug + DataMarker> Debug for Data<M>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<M: DataMarker> DataStore for Data<M>
fn get(self: &Self, id: DataIdentifierBorrowed<'_>, attributes_prefix_match: bool) -> Option<DataPayload<M>>
impl<T> Any for Data<M>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Data<M>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Data<M>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> ErasedDestructor for Data<M>
impl<T> From for Data<M>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Data<M>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Data<M>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Data<M>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>