Struct Cart
struct Cart(_)
The type of the "cart" that is used by DataPayload.
This type is public but the inner cart type is private. To create a
Yoke with this cart, use Cart::try_make_yoke. Then, convert
it to a DataPayload with DataPayload::from_yoked_buffer.
Implementations
impl Clone for Cart
fn clone(self: &Self) -> Cart
impl CloneableCart for Cart
impl Debug for Cart
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for Cart
impl RefUnwindSafe for Cart
impl Send for Cart
impl Sync for Cart
impl Unpin for Cart
impl UnsafeUnpin for Cart
impl UnwindSafe for Cart
impl<T> Any for Cart
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Cart
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Cart
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Cart
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> ErasedDestructor for Cart
impl<T> From for Cart
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Cart
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Cart
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Cart
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Cart
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>