Trait DataProvider

trait DataProvider<M>
where
    M: DataMarker

A data provider that loads data for a specific DataMarkerInfo.

Required Methods

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<M>, DataError>

Query the provider for data, returning the result.

Returns Ok if the request successfully loaded data. If data failed to load, returns an Error with more information.

Implementors