Trait DryDataProvider
trait DryDataProvider<M: DataMarker>: DataProvider<M>
A data provider that can determine whether it can load a particular data identifier, potentially cheaper than actually performing the load.
Required Methods
fn dry_load(self: &Self, req: DataRequest<'_>) -> Result<DataResponseMetadata, DataError>This method goes through the motions of
load, but only returns the metadata.If
dry_loadreturns an error,loadmust return the same error, but not vice-versa. Concretely,loadcould return deserialization or I/O errors thatdry_loadcannot predict.
Implementors
impl<M, P> DryDataProvider for &P